@@ -10,14 +10,20 @@ use bytes::buf::Buf;
 use flate2::read::GzDecoder;
 use http::{Method, StatusCode};
 use lazy_static::lazy_static;
-use protobuf::Message;
+use prost::Message;
 use regex::Regex;
 use ring::digest::{Context, SHA256};
 use serde::Deserialize;
 use serde_json::json;
-use std::{collections::HashMap, convert::TryFrom, convert::TryInto, io::BufReader};
+use std::{
+    collections::HashMap,
+    convert::{TryFrom, TryInto},
+    fmt::Display,
+    io::{BufReader, Read},
+};
 use thiserror::Error;
 use version::{Range, Version};
+use x509_parser::prelude::FromDer;
 
 #[derive(Debug, Clone)]
 pub struct Config {
@@ -55,6 +61,11 @@ impl Config {
         make_request(self.repository_base.clone(), method, path_suffix, api_key)
     }
 }
+impl Default for Config {
+    fn default() -> Self {
+        Self::new()
+    }
+}
 
 fn make_request(
     base: http::Uri,
@@ -82,6 +93,12 @@ fn make_request(
 }
 
 /// Create a request that creates a Hex API key.
+///
+/// API Docs:
+///
+/// https://github.com/hexpm/hex/blob/main/lib/mix/tasks/hex.ex#L137
+///
+/// https://github.com/hexpm/hex/blob/main/lib/hex/api/key.ex#L6
 pub fn create_api_key_request(
     username: &str,
     password: &str,
@@ -119,6 +136,12 @@ pub fn create_api_key_response(response: http::Response<Vec<u8>>) -> Result<Stri
 }
 
 /// Create a request that deletes an Hex API key.
+///
+/// API Docs:
+///
+/// https://github.com/hexpm/hex/blob/main/lib/mix/tasks/hex.user.ex#L291
+///
+/// https://github.com/hexpm/hex/blob/main/lib/hex/api/key.ex#L15
 pub fn remove_api_key_request(
     name_of_key_to_delete: &str,
     api_key: &str,
@@ -131,7 +154,7 @@ pub fn remove_api_key_request(
             Some(api_key),
         )
         .body(vec![])
-        .expect("get_package_tarball_request request")
+        .expect("remove_api_key_request request")
 }
 
 /// Parses a request that deleted a Hex API key.
@@ -146,6 +169,12 @@ pub fn remove_api_key_response(response: http::Response<Vec<u8>>) -> Result<(),
 }
 
 /// Retire an existing package release from Hex.
+///
+/// API Docs:
+///
+/// https://github.com/hexpm/hex/blob/main/lib/mix/tasks/hex.retire.ex#L75
+///
+/// https://github.com/hexpm/hex/blob/main/lib/hex/api/release.ex#L28
 pub fn retire_release_request(
     package: &str,
     version: &str,
@@ -165,7 +194,7 @@ pub fn retire_release_request(
             Some(api_key),
         )
         .body(body.to_string().into_bytes())
-        .expect("require_release_request request")
+        .expect("retire_release_request request")
 }
 
 /// Parses a request that retired a release.
@@ -180,6 +209,12 @@ pub fn retire_release_response(response: http::Response<Vec<u8>>) -> Result<(),
 }
 
 /// Un-retire an existing retired package release from Hex.
+///
+/// API Docs:
+///
+/// https://github.com/hexpm/hex/blob/main/lib/mix/tasks/hex.retire.ex#L89
+///
+/// https://github.com/hexpm/hex/blob/main/lib/hex/api/release.ex#L35
 pub fn unretire_release_request(
     package: &str,
     version: &str,
@@ -193,7 +228,7 @@ pub fn unretire_release_request(
             Some(api_key),
         )
         .body(vec![])
-        .expect("require_release_request request")
+        .expect("unretire_release_request request")
 }
 
 /// Parses a request that un-retired a package version.
@@ -209,7 +244,7 @@ pub fn unretire_release_response(response: http::Response<Vec<u8>>) -> Result<()
 
 /// Create a request that get the names and versions of all of the packages on
 /// the package registry.
-///
+/// TODO: Where are the API docs for this?
 pub fn get_repository_versions_request(
     api_key: Option<&str>,
     config: &Config,
@@ -218,7 +253,7 @@ pub fn get_repository_versions_request(
         .repository_request(Method::GET, "versions", api_key)
         .header("accept", "application/json")
         .body(vec![])
-        .expect("create_api_key_request request")
+        .expect("get_repository_versions_request request")
 }
 
 /// Parse a request that get the names and versions of all of the packages on
@@ -235,26 +270,29 @@ pub fn get_repository_versions_response(
         status => return Err(ApiError::unexpected_response(status, body)),
     };
 
-    let mut body = GzDecoder::new(body.reader());
-    let signed = Signed::parse_from_reader(&mut body)?;
+    let mut decoder = GzDecoder::new(body.reader());
+    let mut body = Vec::new();
+    decoder.read_to_end(&mut body)?;
+
+    let signed = Signed::decode(body.as_slice())?;
 
     let payload =
         verify_payload(signed, public_key).map_err(|_| ApiError::IncorrectPayloadSignature)?;
 
-    let versions = Versions::parse_from_bytes(&payload)?
-        .take_packages()
+    let versions = Versions::decode(payload.as_slice())?
+        .packages
         .into_iter()
-        .map(|mut n| {
+        .map(|n| {
             let parse_version = |v: &str| {
                 let err = |_| ApiError::InvalidVersionFormat(v.to_string());
                 Version::parse(v).map_err(err)
             };
             let versions = n
-                .take_versions()
-                .into_iter()
+                .versions
+                .iter()
                 .map(|v| parse_version(v.as_str()))
                 .collect::<Result<Vec<Version>, ApiError>>()?;
-            Ok((n.take_name(), versions))
+            Ok((n.name, versions))
         })
         .collect::<Result<HashMap<_, _>, ApiError>>()?;
 
@@ -263,6 +301,11 @@ pub fn get_repository_versions_response(
 
 /// Create a request to get the information for a package in the repository.
 ///
+/// API Docs:
+///
+/// https://github.com/hexpm/hex/blob/main/lib/mix/tasks/hex.package.ex#L348
+///
+/// https://github.com/hexpm/hex/blob/main/lib/hex/api/package.ex#L36
 pub fn get_package_request(
     name: &str,
     api_key: Option<&str>,
@@ -285,27 +328,32 @@ pub fn get_package_response(
 
     match parts.status {
         StatusCode::OK => (),
-        StatusCode::FORBIDDEN => return Err(ApiError::NotFound), // Oddly this is the not-found code
+        StatusCode::FORBIDDEN => return Err(ApiError::NotFound),
+        StatusCode::NOT_FOUND => return Err(ApiError::NotFound),
         status => {
             return Err(ApiError::unexpected_response(status, body));
         }
     };
 
-    let mut body = GzDecoder::new(body.reader());
-    let signed = Signed::parse_from_reader(&mut body)?;
+    let mut decoder = GzDecoder::new(body.reader());
+    let mut body = Vec::new();
+    decoder.read_to_end(&mut body)?;
+
+    let signed = Signed::decode(body.as_slice())?;
 
     let payload =
         verify_payload(signed, public_key).map_err(|_| ApiError::IncorrectPayloadSignature)?;
 
-    let mut package = proto::package::Package::parse_from_bytes(&payload)?;
+    let package = proto::package::Package::decode(payload.as_slice())?;
     let releases = package
-        .take_releases()
+        .releases
+        .clone()
         .into_iter()
         .map(proto_to_release)
         .collect::<Result<Vec<_>, _>>()?;
     let package = Package {
-        name: package.take_name(),
-        repository: package.take_repository(),
+        name: package.name,
+        repository: package.repository,
         releases,
     };
 
@@ -313,7 +361,7 @@ pub fn get_package_response(
 }
 
 /// Create a request to download a version of a package as a tarball
-///
+/// TODO: Where are the API docs for this?
 pub fn get_package_tarball_request(
     name: &str,
     version: &str,
@@ -341,6 +389,7 @@ pub fn get_package_tarball_response(
     match parts.status {
         StatusCode::OK => (),
         StatusCode::FORBIDDEN => return Err(ApiError::NotFound),
+        StatusCode::NOT_FOUND => return Err(ApiError::NotFound),
         status => {
             return Err(ApiError::unexpected_response(status, body));
         }
@@ -349,6 +398,11 @@ pub fn get_package_tarball_response(
     Ok(body)
 }
 
+/// API Docs:
+///
+/// https://github.com/hexpm/hex/blob/main/lib/mix/tasks/hex.publish.ex#L384
+///
+/// https://github.com/hexpm/hex/blob/main/lib/hex/api/release_docs.ex#L19
 pub fn remove_docs_request(
     package_name: &str,
     version: &str,
@@ -364,7 +418,7 @@ pub fn remove_docs_request(
             Some(api_key),
         )
         .body(vec![])
-        .expect("get_package_tarball_request request"))
+        .expect("remove_docs_request request"))
 }
 
 pub fn remove_docs_response(response: http::Response<Vec<u8>>) -> Result<(), ApiError> {
@@ -379,6 +433,11 @@ pub fn remove_docs_response(response: http::Response<Vec<u8>>) -> Result<(), Api
     }
 }
 
+/// API Docs:
+///
+/// https://github.com/hexpm/hex/blob/main/lib/mix/tasks/hex.publish.ex#L429
+///
+/// https://github.com/hexpm/hex/blob/main/lib/hex/api/release_docs.ex#L11
 pub fn publish_docs_request(
     package_name: &str,
     version: &str,
@@ -412,6 +471,11 @@ pub fn publish_docs_response(response: http::Response<Vec<u8>>) -> Result<(), Ap
     }
 }
 
+/// API Docs:
+///
+/// https://github.com/hexpm/hex/blob/main/lib/mix/tasks/hex.publish.ex#L512
+///
+/// https://github.com/hexpm/hex/blob/main/lib/hex/api/release.ex#L13
 pub fn publish_package_request(
     release_tarball: Vec<u8>,
     api_key: &str,
@@ -444,12 +508,175 @@ pub fn publish_package_response(response: http::Response<Vec<u8>>) -> Result<(),
             if body.contains("--replace") {
                 return Err(ApiError::NotReplacing);
             }
-            return Err(ApiError::LateModification);
+            Err(ApiError::LateModification)
         }
         status => Err(ApiError::unexpected_response(status, body)),
     }
 }
 
+/// API Docs:
+///
+/// https://github.com/hexpm/hex/blob/main/lib/mix/tasks/hex.publish.ex#L371
+///
+/// https://github.com/hexpm/hex/blob/main/lib/hex/api/release.ex#L21
+pub fn revert_release_request(
+    package_name: &str,
+    version: &str,
+    api_key: &str,
+    config: &Config,
+) -> Result<http::Request<Vec<u8>>, ApiError> {
+    validate_package_and_version(package_name, version)?;
+
+    Ok(config
+        .api_request(
+            Method::DELETE,
+            &format!("packages/{}/releases/{}", package_name, version),
+            Some(api_key),
+        )
+        .body(vec![])
+        .expect("publish_package_request request"))
+}
+
+pub fn revert_release_response(response: http::Response<Vec<u8>>) -> Result<(), ApiError> {
+    let (parts, body) = response.into_parts();
+    match parts.status {
+        StatusCode::NO_CONTENT => Ok(()),
+        StatusCode::NOT_FOUND => Err(ApiError::NotFound),
+        StatusCode::TOO_MANY_REQUESTS => Err(ApiError::RateLimited),
+        StatusCode::UNAUTHORIZED => Err(ApiError::InvalidApiKey),
+        StatusCode::FORBIDDEN => Err(ApiError::Forbidden),
+        status => Err(ApiError::unexpected_response(status, body)),
+    }
+}
+
+/// See: https://github.com/hexpm/hex/blob/main/lib/mix/tasks/hex.owner.ex#L47
+#[derive(Debug, Clone, Copy, PartialEq, Eq, PartialOrd, Ord)]
+pub enum OwnerLevel {
+    /// Has every package permission EXCEPT the ability to change who owns the package
+    Maintainer,
+    /// Has every package permission including the ability to change who owns the package
+    Full,
+}
+
+impl Display for OwnerLevel {
+    fn fmt(&self, f: &mut std::fmt::Formatter<'_>) -> std::fmt::Result {
+        match self {
+            OwnerLevel::Maintainer => write!(f, "maintainer"),
+            OwnerLevel::Full => write!(f, "full"),
+        }
+    }
+}
+
+/// API Docs:
+///
+/// https://github.com/hexpm/hex/blob/main/lib/mix/tasks/hex.owner.ex#L107
+///
+/// https://github.com/hexpm/hex/blob/main/lib/hex/api/package.ex#L19
+pub fn add_owner_request(
+    package_name: &str,
+    owner: &str,
+    level: OwnerLevel,
+    api_key: &str,
+    config: &Config,
+) -> http::Request<Vec<u8>> {
+    let body = json!({
+        "level": level.to_string(),
+        "transfer": false,
+    });
+
+    config
+        .api_request(
+            Method::PUT,
+            &format!("packages/{}/owners/{}", package_name, owner),
+            Some(api_key),
+        )
+        .body(body.to_string().into_bytes())
+        .expect("add_owner_request request")
+}
+
+pub fn add_owner_response(response: http::Response<Vec<u8>>) -> Result<(), ApiError> {
+    let (parts, body) = response.into_parts();
+    match parts.status {
+        StatusCode::NO_CONTENT => Ok(()),
+        StatusCode::NOT_FOUND => Err(ApiError::NotFound),
+        StatusCode::TOO_MANY_REQUESTS => Err(ApiError::RateLimited),
+        StatusCode::UNAUTHORIZED => Err(ApiError::InvalidApiKey),
+        StatusCode::FORBIDDEN => Err(ApiError::Forbidden),
+        status => Err(ApiError::unexpected_response(status, body)),
+    }
+}
+
+/// API Docs:
+///
+/// https://github.com/hexpm/hex/blob/main/lib/mix/tasks/hex.owner.ex#L125
+///
+/// https://github.com/hexpm/hex/blob/main/lib/hex/api/package.ex#L19
+pub fn transfer_owner_request(
+    package_name: &str,
+    owner: &str,
+    api_key: &str,
+    config: &Config,
+) -> http::Request<Vec<u8>> {
+    let body = json!({
+        "level": OwnerLevel::Full.to_string(),
+        "transfer": true,
+    });
+
+    config
+        .api_request(
+            Method::PUT,
+            &format!("packages/{}/owners/{}", package_name, owner),
+            Some(api_key),
+        )
+        .body(body.to_string().into_bytes())
+        .expect("transfer_owner_request request")
+}
+
+pub fn transfer_owner_response(response: http::Response<Vec<u8>>) -> Result<(), ApiError> {
+    let (parts, body) = response.into_parts();
+    match parts.status {
+        StatusCode::NO_CONTENT => Ok(()),
+        StatusCode::NOT_FOUND => Err(ApiError::NotFound),
+        StatusCode::TOO_MANY_REQUESTS => Err(ApiError::RateLimited),
+        StatusCode::UNAUTHORIZED => Err(ApiError::InvalidApiKey),
+        StatusCode::FORBIDDEN => Err(ApiError::Forbidden),
+        status => Err(ApiError::unexpected_response(status, body)),
+    }
+}
+
+/// API Docs:
+///
+/// https://github.com/hexpm/hex/blob/main/lib/mix/tasks/hex.owner.ex#L139
+///
+/// https://github.com/hexpm/hex/blob/main/lib/hex/api/package.ex#L28
+pub fn remove_owner_request(
+    package_name: &str,
+    owner: &str,
+    api_key: &str,
+    config: &Config,
+) -> http::Request<Vec<u8>> {
+    config
+        .api_request(
+            Method::DELETE,
+            &format!("packages/{}/owners/{}", package_name, owner),
+            Some(api_key),
+        )
+        .body(vec![])
+        .expect("remove_owner_request request")
+}
+
+pub fn remove_owner_response(response: http::Response<Vec<u8>>) -> Result<(), ApiError> {
+    let (parts, body) = response.into_parts();
+    match parts.status {
+        StatusCode::NO_CONTENT => Ok(()),
+        StatusCode::NOT_FOUND => Err(ApiError::NotFound),
+        StatusCode::TOO_MANY_REQUESTS => Err(ApiError::RateLimited),
+        StatusCode::UNAUTHORIZED => Err(ApiError::InvalidApiKey),
+        StatusCode::FORBIDDEN => Err(ApiError::Forbidden),
+        status => Err(ApiError::unexpected_response(status, body)),
+    }
+}
+
 #[derive(Error, Debug)]
 pub enum ApiError {
     #[error(transparent)]
@@ -474,7 +701,7 @@ pub enum ApiError {
     IncorrectPayloadSignature,
 
     #[error(transparent)]
-    InvalidProtobuf(#[from] protobuf::ProtobufError),
+    InvalidProtobuf(#[from] prost::DecodeError),
 
     #[error("unexpected version format {0}")]
     InvalidVersionFormat(String),
@@ -541,64 +768,53 @@ fn read_and_check_body(reader: impl std::io::Read, checksum: &[u8]) -> Result<Ve
 }
 
 fn proto_to_retirement_status(
-    mut status: proto::package::RetirementStatus,
+    status: Option<proto::package::RetirementStatus>,
 ) -> Option<RetirementStatus> {
-    if status.has_reason() {
-        Some(RetirementStatus {
-            message: status.take_message(),
-            reason: proto_to_retirement_reason(status.get_reason()),
-        })
-    } else {
-        None
-    }
+    status.map(|stat| RetirementStatus {
+        message: stat.message().into(),
+        reason: proto_to_retirement_reason(stat.reason()),
+    })
 }
 
 fn proto_to_retirement_reason(reason: proto::package::RetirementReason) -> RetirementReason {
     use proto::package::RetirementReason::*;
     match reason {
-        RETIRED_OTHER => RetirementReason::Other,
-        RETIRED_INVALID => RetirementReason::Invalid,
-        RETIRED_SECURITY => RetirementReason::Security,
-        RETIRED_DEPRECATED => RetirementReason::Deprecated,
-        RETIRED_RENAMED => RetirementReason::Renamed,
+        RetiredOther => RetirementReason::Other,
+        RetiredInvalid => RetirementReason::Invalid,
+        RetiredSecurity => RetirementReason::Security,
+        RetiredDeprecated => RetirementReason::Deprecated,
+        RetiredRenamed => RetirementReason::Renamed,
     }
 }
 
-fn proto_to_dep(mut dep: proto::package::Dependency) -> Result<(String, Dependency), ApiError> {
-    let app = if dep.has_app() {
-        Some(dep.take_app())
-    } else {
-        None
-    };
-    let repository = if dep.has_repository() {
-        Some(dep.take_repository())
-    } else {
-        None
-    };
-    let requirement = Range::new(dep.take_requirement());
+fn proto_to_dep(dep: proto::package::Dependency) -> Result<(String, Dependency), ApiError> {
+    let app = dep.app;
+    let repository = dep.repository;
+    let requirement = Range::new(dep.requirement);
     Ok((
-        dep.take_package(),
+        dep.package,
         Dependency {
             requirement,
-            optional: dep.has_optional(),
+            optional: dep.optional.is_some(),
             app,
             repository,
         },
     ))
 }
 
-fn proto_to_release(mut release: proto::package::Release) -> Result<Release<()>, ApiError> {
+fn proto_to_release(release: proto::package::Release) -> Result<Release<()>, ApiError> {
     let dependencies = release
-        .take_dependencies()
+        .dependencies
+        .clone()
         .into_iter()
         .map(proto_to_dep)
         .collect::<Result<HashMap<_, _>, _>>()?;
-    let version =
-        Version::try_from(release.get_version()).expect("Failed to parse version format from Hex");
+    let version = Version::try_from(release.version.as_str())
+        .expect("Failed to parse version format from Hex");
     Ok(Release {
         version,
-        outer_checksum: release.take_outer_checksum(),
-        retirement_status: proto_to_retirement_status(release.take_retired()),
+        outer_checksum: release.outer_checksum.unwrap_or_default(),
+        retirement_status: proto_to_retirement_status(release.retired),
         requirements: dependencies,
         meta: (),
     })
@@ -734,8 +950,8 @@ static USER_AGENT: &str = concat!(env!("CARGO_PKG_NAME"), " (", env!("CARGO_PKG_
 
 fn validate_package_and_version(package: &str, version: &str) -> Result<(), ApiError> {
     lazy_static! {
-        static ref PACKAGE_PATTERN: Regex = Regex::new(r#"^[a-z_-]+$"#).unwrap();
-        static ref VERSION_PATTERN: Regex = Regex::new(r#"^[a-zA-Z-0-9\._-]+$"#).unwrap();
+        static ref PACKAGE_PATTERN: Regex = Regex::new(r"^[a-z]\w*$").unwrap();
+        static ref VERSION_PATTERN: Regex = Regex::new(r"^[a-zA-Z-0-9\._-]+$").unwrap();
     }
     if !PACKAGE_PATTERN.is_match(package) {
         return Err(ApiError::InvalidPackageNameFormat(package.to_string()));
@@ -762,12 +978,12 @@ fn verify_payload(mut signed: Signed, pem_public_key: &[u8]) -> Result<Vec<u8>,
         .map_err(|_| ApiError::IncorrectPayloadSignature)?;
     let (_, spki) = x509_parser::prelude::SubjectPublicKeyInfo::from_der(&pem.contents)
         .map_err(|_| ApiError::IncorrectPayloadSignature)?;
-    let payload = signed.take_payload();
+    let payload = std::mem::take(&mut signed.payload);
     let verification = ring::signature::UnparsedPublicKey::new(
         &ring::signature::RSA_PKCS1_2048_8192_SHA512,
         &spki.subject_public_key,
     )
-    .verify(payload.as_slice(), signed.get_signature());
+    .verify(payload.as_slice(), signed.signature());
 
     if verification.is_ok() {
         Ok(payload)
