@@ -24,9 +24,13 @@ pub enum Error {
     EmptyPredicate,
     /// Encountered an empty range.
     EmptyRange,
+    /// Encountered a semver that's missing the minor and patch version.
+    MinorVersionMissing(u32),
+    /// Encountered a semver that's missing the patch version.
+    PatchVersionMissing(u32, u32),
 }
 
-impl<'input> From<lexer::Error> for Error {
+impl From<lexer::Error> for Error {
     fn from(value: lexer::Error) -> Self {
         Error::Lexer(value)
     }
@@ -43,6 +47,12 @@ impl fmt::Display for Error {
             MoreInput(ref tokens) => write!(fmt, "expected end of input, but got: {:?}", tokens),
             EmptyPredicate => write!(fmt, "encountered empty predicate"),
             EmptyRange => write!(fmt, "encountered empty range"),
+            MinorVersionMissing(major) => {
+                write!(fmt, "missing minor and patch versions: {:?}", major)
+            }
+            PatchVersionMissing(major, minor) => {
+                write!(fmt, "missing patch version: {:?}.{:?}", major, minor)
+            }
         }
     }
 }
@@ -222,8 +232,12 @@ impl<'input> Parser<'input> {
         self.skip_whitespace()?;
 
         let major = self.numeric()?;
-        let minor = self.dot_numeric()?;
-        let patch = self.dot_numeric()?;
+        let minor = self
+            .dot_numeric()
+            .map_err(|_| Error::MinorVersionMissing(major))?;
+        let patch = self
+            .dot_numeric()
+            .map_err(|_| Error::PatchVersionMissing(major, minor))?;
         let pre = self.pre()?;
         let build = self.plus_build_metadata()?;
 
